==> haskell-wl-pprint-annotated-0.1.0.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.0
id: wl-pprint-annotated-0.1.0.0-Ki9jUbY5SKn3UhZMlHq5J
key: wl-pprint-annotated-0.1.0.0-Ki9jUbY5SKn3UhZMlHq5J
license: BSD3
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Wadler/Leijen pretty printer with annotations and slightly modernized API
description:
    Wadler/Leijen pretty printer with annotations and slightly modernized API
category: Text
author: Daniel Mendler <mail@daniel-mendler.de>
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Annotated.WL
abi: 382f04a3767cbdb5b2cf06d9db840767
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-annotated-0.1.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-annotated-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-annotated-0.1.0.0
hs-libraries: HSwl-pprint-annotated-0.1.0.0-Ki9jUbY5SKn3UhZMlHq5J
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-annotated-0.1.0.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.0
id: wl-pprint-annotated-0.1.0.0-4lNw2rvviI5EPIiCeAaaam
key: wl-pprint-annotated-0.1.0.0-4lNw2rvviI5EPIiCeAaaam
license: BSD3
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Wadler/Leijen pretty printer with annotations and slightly modernized API
description:
    Wadler/Leijen pretty printer with annotations and slightly modernized API
category: Text
author: Daniel Mendler <mail@daniel-mendler.de>
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Annotated.WL
abi: 777b11d98374536b1847defd01513a1e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-annotated-0.1.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-annotated-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-annotated-0.1.0.0
hs-libraries: HSwl-pprint-annotated-0.1.0.0-4lNw2rvviI5EPIiCeAaaam
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
